@@ -26,12 +26,21 @@ FAILEDOPERATION = 'FailedOperation'
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# agent执行脚本失败。
+INTERNALERROR_AGENTRUNSCRIPTFAIL = 'InternalError.AgentRunScriptFail'
+
+# CAM服务调用失败。
+INTERNALERROR_CALLCAM = 'InternalError.CallCAM'
+
 # cvm调用失败。
 INTERNALERROR_CALLCVM = 'InternalError.CallCvm'
 
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 参数互斥，最多只能传入一个参数
+INVALIDPARAMETER_ATMOSTONE = 'InvalidParameter.AtMostOne'
+
 # 参数格式有误。
 INVALIDPARAMETER_MALFORMED = 'InvalidParameter.Malformed'
 
@@ -41,6 +50,9 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 不支持指定过滤器的键。
 INVALIDPARAMETERVALUE_INVALIDFILTERNOTSUPPORTEDNAME = 'InvalidParameterValue.InvalidFilterNotSupportedName'
 
+# 工作空间实例ID格式不符合规范。
+INVALIDPARAMETERVALUE_INVALIDSPACEIDMALFORMED = 'InvalidParameterValue.InvalidSpaceIdMalformed'
+
 # 参数值数量超过限制。
 INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 
